@@ -12,7 +12,8 @@ class ColMapper:
             displacementYCol='displacementY',
             localXCol='localX',
             localYCol='localY',
-        
+            verticalDirectionCol='verticalDirection',
+            horizontalDirectionCol='horizontalDirection'
         ):
         
         self.idCol = idCol
@@ -29,4 +30,7 @@ class ColMapper:
         self.localXCol = localXCol
         self.localYCol = localYCol
 
+        self.verticalDirectionCol = verticalDirectionCol
+        self.horizontalDirectionCol = horizontalDirectionCol
+
         pass
\ No newline at end of file
